==> guildai-0.8.1rc1-py2.py3-none-any.whl: guild/tests/uat/install-test-deps.md <==
# Install test dependencies

Tests require additional packages that are not included in the Guild
distribution or requirements.txt. They are defined in
guild/tests/requirements.txt.

    >>> quiet("pip install -r $GUILD_PKGDIR/guild/tests/requirements.txt", timeout=300)

Run Guild check with verbose to show various module versions. We need
different tests for different versions of Python.

Python 3.6:

    >>> run("guild check --verbose --offline")  # doctest: -PY2 -PY3 +PY36
    guild_version:             ...
    psutil_version:            5.9.0
    tensorboard_version:       2.8.0
    cuda_version:              ...
    nvidia_smi_version:        ...
    click_version:             8.0.4
    dask_version:              2021...
    distutils_version:         ...
    numpy_version:             1.19...
    pandas_version:            1.1.5
    pip_version:               18.0
    sklearn_version:           0.24.2
    skopt_version:             0.9.0
    setuptools_version:        ...
    twine_version:             3.8...
    yaml_version:              6.0
    werkzeug_version:          2...
    latest_guild_version:      ...
    <exit 0>

Python 3.7:

    >>> run("guild check --verbose --offline")  # doctest: -PY2 -PY3 +PY37
    guild_version:             ...
    psutil_version:            5.9.0
    tensorboard_version:       2.8.0
    cuda_version:              ...
    nvidia_smi_version:        ...
    click_version:             8.1...
    dask_version:              2022...
    distutils_version:         ...
    numpy_version:             1.21...
    pandas_version:            1.3.5
    pip_version:               18.0
    sklearn_version:           1.0...
    skopt_version:             0.9.0
    setuptools_version:        ...
    twine_version:             4.0...
    yaml_version:              6.0
    werkzeug_version:          2...
    latest_guild_version:      ...
    <exit 0>

Python 3.8:

    >>> run("guild check --verbose --offline")  # doctest: -PY2 -PY3 +PY38
    guild_version:             ...
    psutil_version:            5.9.0
    tensorboard_version:       2.8.0
    cuda_version:              ...
    nvidia_smi_version:        ...
    click_version:             8.1...
    dask_version:              2022...
    distutils_version:         ...
    numpy_version:             1.22...
    pandas_version:            1.4...
    pip_version:               18.0
    sklearn_version:           1.0...
    skopt_version:             0.9.0
    setuptools_version:        ...
    twine_version:             4.0...
    yaml_version:              6.0
    werkzeug_version:          2...
    latest_guild_version:      ...
    <exit 0>

Python 3.9:

    >>> run("guild check --verbose --offline")  # doctest: -PY2 -PY3 +PY39
    guild_version:             ...
    psutil_version:            5.9.0
    tensorboard_version:       2.8.0
    cuda_version:              ...
    nvidia_smi_version:        ...
    click_version:             8.1...
    dask_version:              2022...
    distutils_version:         ...
    numpy_version:             1.22...
    pandas_version:            1.4...
    pip_version:               18.0
    sklearn_version:           1.0...
    skopt_version:             0.9.0
    setuptools_version:        ...
    twine_version:             4.0...
    yaml_version:              6.0
    werkzeug_version:          2...
    latest_guild_version:      ...
    <exit 0>

Python 3.10:

    >>> run("guild check --verbose --offline")  # doctest: -PY2 -PY3 +PY310
    guild_version:             ...
    psutil_version:            5.9.0
    tensorboard_version:       2.8.0
    cuda_version:              ...
    nvidia_smi_version:        ...
    click_version:             8.1...
    dask_version:              2022...
    distutils_version:         ...
    numpy_version:             1.22...
    pandas_version:            1.4...
    pip_version:               18.0
    sklearn_version:           1.0...
    skopt_version:             0.9.0
    setuptools_version:        ...
    twine_version:             4.0...
    yaml_version:              6.0
    werkzeug_version:          2...
    latest_guild_version:      ...
    <exit 0>

==> guildai-0.8.2.dev1-py2.py3-none-any.whl: guild/tests/uat/install-test-deps.md <==
# Install test dependencies

Tests require additional packages that are not included in the Guild
distribution or requirements.txt. They are defined in
guild/tests/requirements.txt.

    >>> quiet("pip install -r $GUILD_PKGDIR/guild/tests/requirements.txt")

Run Guild check with verbose to show various module versions. We need
different tests for different versions of Python.

Python 3.6:

    >>> run("guild check --verbose --offline")  # doctest: -PY3 +PY36
    guild_version:             ...
    psutil_version:            5.9...
    tensorboard_version:       2.10...
    cuda_version:              ...
    nvidia_smi_version:        ...
    click_version:             8.0.4
    dask_version:              2021...
    distutils_version:         ...
    numpy_version:             1.19...
    pandas_version:            1.1.5
    pip_version:               ...
    sklearn_version:           0.24.2
    skopt_version:             0.9.0
    setuptools_version:        ...
    twine_version:             3.8...
    yaml_version:              6.0
    werkzeug_version:          2...
    latest_guild_version:      ...
    <exit 0>

Python 3.7:

    >>> run("guild check --verbose --offline")  # doctest: -PY3 +PY37
    guild_version:             ...
    psutil_version:            5.9...
    tensorboard_version:       2.10...
    cuda_version:              ...
    nvidia_smi_version:        ...
    click_version:             8.1...
    dask_version:              2022...
    distutils_version:         ...
    numpy_version:             1.21...
    pandas_version:            1.3.5
    pip_version:               ...
    sklearn_version:           1.0...
    skopt_version:             0.9.0
    setuptools_version:        ...
    twine_version:             4.0...
    yaml_version:              6.0
    werkzeug_version:          2...
    latest_guild_version:      ...
    <exit 0>

Python 3.8:

    >>> run("guild check --verbose --offline")  # doctest: -PY3 +PY38
    guild_version:             ...
    psutil_version:            5.9...
    tensorboard_version:       2.10...
    cuda_version:              ...
    nvidia_smi_version:        ...
    click_version:             8.1...
    dask_version:              2022...
    distutils_version:         ...
    numpy_version:             1.23...
    pandas_version:            1.5...
    pip_version:               ...
    sklearn_version:           1.1...
    skopt_version:             0.9.0
    setuptools_version:        ...
    twine_version:             4.0...
    yaml_version:              6.0
    werkzeug_version:          2...
    latest_guild_version:      ...
    <exit 0>

Python 3.9:

    >>> run("guild check --verbose --offline")  # doctest: -PY3 +PY39
    guild_version:             ...
    psutil_version:            5.9...
    tensorboard_version:       2.10...
    cuda_version:              ...
    nvidia_smi_version:        ...
    click_version:             8.1...
    dask_version:              2022...
    distutils_version:         ...
    numpy_version:             1.23...
    pandas_version:            1.5...
    pip_version:               ...
    sklearn_version:           1.1...
    skopt_version:             0.9.0
    setuptools_version:        ...
    twine_version:             4.0...
    yaml_version:              6.0
    werkzeug_version:          2...
    latest_guild_version:      ...
    <exit 0>

Python 3.10:

    >>> run("guild check --verbose --offline")  # doctest: -PY3 +PY310
    guild_version:             ...
    psutil_version:            5.9...
    tensorboard_version:       2.10...
    cuda_version:              ...
    nvidia_smi_version:        ...
    click_version:             8.1...
    dask_version:              2022...
    distutils_version:         ...
    numpy_version:             1.23...
    pandas_version:            1.5...
    pip_version:               ...
    sklearn_version:           1.1...
    skopt_version:             0.9.0
    setuptools_version:        ...
    twine_version:             4.0...
    yaml_version:              6.0
    werkzeug_version:          2...
    latest_guild_version:      ...
    <exit 0>
